@@ -19,7 +19,7 @@
 
 import errno
 import os
-import pipes
+import re
 import shutil
 import shlex
 import sys
@@ -211,8 +211,12 @@ def get_pbuilder_dist(options, repo, native=False):
         parts = branch.rsplit('/')
         if len(parts) == 2:  # e.g. debian/stretch
             suite = parts[1]
+            # Strip numeral prefix if suite name has it
+            # e.g. '12-bookworm' or '24.04-noble'
+            suite = re.sub(r'^[0-9][0-9.]*-', '', suite)
             if vendor == parts[0]:
-                dist = '' if suite in ['sid', 'master', 'main', 'latest'] else suite
+                # Keep 'dist' empty for Debian unstable, otherwise populate it with 'suite'
+                dist = '' if suite in ['latest', 'master', 'main', 'sid'] else suite
             else:
                 dist = '%s_%s' % (parts[0], suite)
         # Branches in Debian often omit the debian/ prefix
@@ -486,6 +490,7 @@ def main(argv):
     prefix = "git-"
     source = None
     hook_env = {}
+    export_dir = None
 
     options, gbp_args, dpkg_args = parse_args(argv, prefix)
 
@@ -570,7 +575,7 @@ def main(argv):
             # Finally build the package:
             gbp.log.info("Performing the build")
             RunAtCommand(options.builder,
-                         [pipes.quote(arg) for arg in dpkg_args],
+                         [shlex.quote(arg) for arg in dpkg_args],
                          shell=True,
                          extra_env=Hook.md(build_env,
                                            {'GBP_BUILD_DIR': build_dir})
@@ -602,7 +607,7 @@ def main(argv):
         drop_index(repo)
 
     if not options.tag_only:
-        if options.export_dir and options.purge and not retval:
+        if export_dir and options.purge:
             RemoveTree(export_dir)()
 
         if source:
