@@ -23,8 +23,6 @@ from tests.component import (ComponentTestBase,
                              skipUnless)
 from tests.component.deb.fixtures import RepoFixtures
 
-from nose.tools import ok_
-
 from gbp.scripts.clone import main as clone
 
 
@@ -34,14 +32,15 @@ class TestClone(ComponentTestBase):
     @RepoFixtures.native()
     def test_clone_nonempty(self, repo):
         """Test that cloning into an existing dir fails"""
-        os.chdir('..')
-        ok_(clone(['arg0', repo.path]) == 1,
-            "Cloning did no fail as expected")
-        self._check_log(-2,
-                        "gbp:error: Git command failed: Error "
-                        "running git clone: fatal: destination path "
-                        "'git-buildpackage' already exists and is not "
-                        "an empty directory.")
+        os.chdir("..")
+        assert clone(["arg0", repo.path]) == 1, "Cloning did no fail as expected"
+        self._check_log(
+            -2,
+            "gbp:error: Git command failed: Error "
+            "running git clone: fatal: destination path "
+            "'git-buildpackage' already exists and is not "
+            "an empty directory.",
+        )
 
     @RepoFixtures.native()
     def test_clone_native(self, repo):
@@ -61,8 +60,7 @@ class TestClone(ComponentTestBase):
         """Test that cloning from vcs-git urls works"""
         dest = os.path.join(self._tmpdir,
                             'cloned_repo')
-        ret = clone(['arg0', "--add-upstream-vcs", "vcsgit:libvirt-glib", dest])
-        self.assertEqual(ret, 0)
+        self._check_success(clone(['arg0', "--add-upstream-vcs", "vcsgit:libvirt-glib", dest]))
         cloned = ComponentTestGitRepository(dest)
         self._check_repo_state(cloned, 'debian/sid', ['debian/sid', 'upstream/latest'])
         assert cloned.has_remote_repo("upstreamvcs")
@@ -80,8 +78,7 @@ class TestClone(ComponentTestBase):
         """Test that cloning from github urls works"""
         dest = os.path.join(self._tmpdir,
                             'cloned_repo')
-        ret = clone(['arg0', "github:agx/git-buildpackage", dest])
-        self.assertEqual(ret, 0)
+        self._check_success(clone(['arg0', "github:agx/git-buildpackage", dest]))
         cloned = ComponentTestGitRepository(dest)
         self._check_repo_state(cloned, 'master', ['master'])
 
@@ -90,8 +87,7 @@ class TestClone(ComponentTestBase):
         """Test that cloning a repo without harmful attrs does nothing"""
         dest = os.path.join(self._tmpdir,
                             'cloned_repo')
-        clone(['arg0',
-               repo.path, dest])
+        self._check_success(clone(['arg0', repo.path, dest]))
         cloned = ComponentTestGitRepository(dest)
         self._check_repo_state(cloned, 'master', ['master'])
 
@@ -116,7 +112,7 @@ class TestClone(ComponentTestBase):
         self._check_repo_state(cloned, 'master', ['master'])
 
         attrs_file = os.path.join(dest, '.git', 'info', 'attributes')
-        ok_(os.path.exists(attrs_file), "%s is missing" % attrs_file)
+        assert os.path.exists(attrs_file), "%s is missing" % attrs_file
 
         with open(attrs_file) as f:
             attrs = sorted(f.read().splitlines())
